@@ -78,16 +78,16 @@ void PersonalDataPage::slotRadioButtonClicked(QAbstractButton *button)
 {
     QString smptHostname;
     if (!mIspdb->smtpServers().isEmpty()) {
-        Server s = mIspdb->smtpServers().at(0);
+        const Server s = mIspdb->smtpServers().at(0);
         smptHostname = s.hostname;
     }
     ui.outgoingLabel->setText(i18n("SMTP, %1", smptHostname));
     if (button == ui.imapAccount) {
-        Server simap = mIspdb->imapServers().at(0); // should be ok.
+        const Server simap = mIspdb->imapServers().at(0); // should be ok.
         ui.incommingLabel->setText(i18n("IMAP, %1", simap.hostname));
         ui.usernameLabel->setText(simap.username);
     } else if (button == ui.pop3Account) {
-        Server spop3 = mIspdb->pop3Servers().at(0); // should be ok.
+        const Server spop3 = mIspdb->pop3Servers().at(0); // should be ok.
         ui.incommingLabel->setText(i18n("POP3, %1", spop3.hostname));
         ui.usernameLabel->setText(spop3.username);
     }
@@ -168,7 +168,7 @@ void PersonalDataPage::slotSearchType(const QString &type)
 void PersonalDataPage::configureSmtpAccount()
 {
     if (!mIspdb->smtpServers().isEmpty()) {
-        Server s = mIspdb->smtpServers().at(0); // should be ok.
+        const Server s = mIspdb->smtpServers().at(0); // should be ok.
         qCDebug(ACCOUNTWIZARD_LOG) << "Configuring transport for" << s.hostname;
 
         QObject *object = mSetupManager->createTransport(QStringLiteral("smtp"));
