@@ -21,7 +21,7 @@
 #define SETUPMANAGER_H
 
 #include <QObject>
-
+#include <QVector>
 #include "key.h"
 #include <gpgme++/key.h>
 
@@ -49,8 +49,8 @@ public:
     void setKey(const GpgME::Key &key);
     void setKeyPublishingMethod(Key::PublishingMethod method);
 
-    QList<SetupObject *> objectsToSetup() const;
-    QList<SetupObject *> setupObjects() const;
+    QVector<SetupObject *> objectsToSetup() const;
+    QVector<SetupObject *> setupObjects() const;
 
 public Q_SLOTS:
     Q_SCRIPTABLE bool personalDataAvailable();
@@ -87,17 +87,17 @@ private Q_SLOTS:
 
 private:
     QString m_name, m_email, m_password;
-    QList<SetupObject *> m_objectToSetup;
-    QList<SetupObject *> m_setupObjects;
+    QVector<SetupObject *> m_objectToSetup;
+    QVector<SetupObject *> m_setupObjects;
     SetupObject *m_currentSetupObject = nullptr;
     SetupPage *m_page = nullptr;
     KWallet::Wallet *m_wallet = nullptr;
     GpgME::Key m_key;
     Key::PublishingMethod m_keyPublishingMethod;
-    bool m_personalDataAvailable;
-    bool m_rollbackRequested;
-    bool m_pgpAutoSign;
-    bool m_pgpAutoEncrypt;
+    bool m_personalDataAvailable = false;
+    bool m_rollbackRequested = false;
+    bool m_pgpAutoSign = false;
+    bool m_pgpAutoEncrypt = false;
 };
 
 #endif
